<template>
    <div data-pc-preset="preset-1" data-pc-sidebar-theme="light" data-pc-sidebar-caption="true" data-pc-direction="ltr"
         data-pc-theme="light">
        <Sidenav/>
        <Navbar/>
        <div class="pc-container">
            <div class="pc-content">
                <slot/>
            </div>
        </div>
        <Footer/>
    </div>
</template>

<script setup>

import {usePage} from "@inertiajs/vue3";
import {computed, onMounted, watch} from "vue";
import {toast} from "vue3-toastify";
import {useGlobalStore} from "@/Store/GlobalStore.js";
import {storeToRefs} from "pinia";
import Footer from "@/Components/Admin/Template/Footer.vue";
import Navbar from "@/Components/Admin/Template/Navbar.vue";
import Sidenav from "@/Components/Admin/Template/Sidenav.vue";

const store = useGlobalStore();
const {
    loading
} = storeToRefs(store);

const page = usePage();
const flashMessages = computed(() => page.props.flashMessages);

watch(flashMessages, (value) => {
    console.log('flashMessages', value);
    if (value.success) toast.success(value.success);
    if (value.error) toast.error(value.error);
});

onMounted(() => {
    if (page.props.flashMessages.success) {
        toast.success(page.props.flashMessages.success);
    }

    if (page.props.flashMessages.error) {
        toast.error(page.props.flashMessages.error);
    }
});
</script>
